@@ -312,16 +312,20 @@ export class Explore extends PureComponent<Props, ExploreState> {
    */
   onSplitOpen = (panelType: string) => {
     return async (options?: SplitOpenOptions) => {
-      let compact = true;
+      let compact = false;
 
       /**
        * Temporary fix grafana-clickhouse-datasource as it requires the query editor to be fully rendered to update the query
        * Proposed fixes:
        * - https://github.com/grafana/clickhouse-datasource/issues/1363 - handle query update in data source
        * - https://github.com/grafana/grafana/issues/110868 - allow data links to provide meta info if the link can be handled in compact mode (default to false)
+       * Update:
+       * More data source may struggle with this setting: https://github.com/grafana/grafana/issues/112075
+       * We're making it enabled for tempo only and will try to make it optional for other data sources in the future.
        */
-      if (options?.queries?.some((q) => q.datasource?.type === 'grafana-clickhouse-datasource')) {
-        compact = false;
+      const dsType = getDataSourceSrv().getInstanceSettings({ uid: options?.datasourceUid })?.type;
+      if (dsType === 'tempo' || options?.queries?.every((q) => q.datasource?.type === 'tempo')) {
+        compact = true;
       }
 
       this.props.splitOpen(options ? { ...options, compact } : options);
@@ -707,29 +711,59 @@ export class Explore extends PureComponent<Props, ExploreState> {
 
                         return (
                           <main className={cx(styles.exploreMain)} style={{ width }}>
-                            <ErrorBoundaryAlert>
+                            <ErrorBoundaryAlert boundaryName="explore-main">
                               {showPanels && (
                                 <>
                                   {showMetrics && graphResult && (
-                                    <ErrorBoundaryAlert>{this.renderGraphPanel(width)}</ErrorBoundaryAlert>
+                                    <ErrorBoundaryAlert boundaryName="explore-graph-panel">
+                                      {this.renderGraphPanel(width)}
+                                    </ErrorBoundaryAlert>
                                   )}
                                   {showRawPrometheus && (
-                                    <ErrorBoundaryAlert>{this.renderRawPrometheus(width)}</ErrorBoundaryAlert>
+                                    <ErrorBoundaryAlert boundaryName="explore-raw-prometheus">
+                                      {this.renderRawPrometheus(width)}
+                                    </ErrorBoundaryAlert>
+                                  )}
+                                  {showTable && (
+                                    <ErrorBoundaryAlert boundaryName="explore-table-panel">
+                                      {this.renderTablePanel(width)}
+                                    </ErrorBoundaryAlert>
+                                  )}
+                                  {showLogs && (
+                                    <ErrorBoundaryAlert boundaryName="explore-logs-panel">
+                                      {this.renderLogsPanel(width)}
+                                    </ErrorBoundaryAlert>
                                   )}
-                                  {showTable && <ErrorBoundaryAlert>{this.renderTablePanel(width)}</ErrorBoundaryAlert>}
-                                  {showLogs && <ErrorBoundaryAlert>{this.renderLogsPanel(width)}</ErrorBoundaryAlert>}
                                   {showNodeGraph && (
-                                    <ErrorBoundaryAlert>{this.renderNodeGraphPanel()}</ErrorBoundaryAlert>
+                                    <ErrorBoundaryAlert boundaryName="explore-node-graph-panel">
+                                      {this.renderNodeGraphPanel()}
+                                    </ErrorBoundaryAlert>
                                   )}
                                   {showFlameGraph && (
-                                    <ErrorBoundaryAlert>{this.renderFlameGraphPanel()}</ErrorBoundaryAlert>
+                                    <ErrorBoundaryAlert boundaryName="explore-flame-graph-panel">
+                                      {this.renderFlameGraphPanel()}
+                                    </ErrorBoundaryAlert>
+                                  )}
+                                  {showTrace && (
+                                    <ErrorBoundaryAlert boundaryName="explore-trace-view-panel">
+                                      {this.renderTraceViewPanel()}
+                                    </ErrorBoundaryAlert>
                                   )}
-                                  {showTrace && <ErrorBoundaryAlert>{this.renderTraceViewPanel()}</ErrorBoundaryAlert>}
                                   {showLogsSample && (
-                                    <ErrorBoundaryAlert>{this.renderLogsSamplePanel()}</ErrorBoundaryAlert>
+                                    <ErrorBoundaryAlert boundaryName="explore-logs-sample-panel">
+                                      {this.renderLogsSamplePanel()}
+                                    </ErrorBoundaryAlert>
+                                  )}
+                                  {showCustom && (
+                                    <ErrorBoundaryAlert boundaryName="explore-custom-panel">
+                                      {this.renderCustom(width)}
+                                    </ErrorBoundaryAlert>
+                                  )}
+                                  {showNoData && (
+                                    <ErrorBoundaryAlert boundaryName="explore-no-data">
+                                      {this.renderNoData()}
+                                    </ErrorBoundaryAlert>
                                   )}
-                                  {showCustom && <ErrorBoundaryAlert>{this.renderCustom(width)}</ErrorBoundaryAlert>}
-                                  {showNoData && <ErrorBoundaryAlert>{this.renderNoData()}</ErrorBoundaryAlert>}
                                 </>
                               )}
                             </ErrorBoundaryAlert>
